[![docs master](https://readthedocs.org/projects/python-peerplays/badge/?version=master)](http://python-peerplays.readthedocs.io/en/latest/)
[![Build Status](https://travis-ci.org/PBSA/python-peerplays.svg?branch=master)](https://travis-ci.org/PBSA/python-peerplays)
[![codecov](https://codecov.io/gh/pbsa/python-peerplays/branch/master/graph/badge.svg)](https://codecov.io/gh/pbsa/python-peerplays)

## Develop:

[![docs master](https://readthedocs.org/projects/python-peerplays/badge/?version=develop)](http://python-peerplays.readthedocs.io/en/latest/)
[![Build Status](https://travis-ci.org/PBSA/python-peerplays.svg?branch=develop)](https://travis-ci.org/PBSA/python-peerplays)
[![codecov](https://codecov.io/gh/pbsa/python-peerplays/branch/develop/graph/badge.svg)](https://codecov.io/gh/pbsa/python-peerplays)

Python Library for PeerPlays
========================

Python 3 library for PeerPlays!

Installation
------------

Install with `pip3`:

    $ pip3 install peerplays
